==> elektra-0.8.21.tar.gz: elektra-0.8.21/doc/AUTHORS.md <==
# Authors

This is a list of people that contributed to the Elektra project.


## Markus Raab

maintainer, main development, documentation, quality

- email: elektra@libelektra.org
- devel/test on: Debian


## Manuel Mausz

bindings, swig, gobject, main development

- email: manuel-elektra@mausz.at
- devel/test on: Fedora


## Felix Berlakovich

journald plugin, augeas plugin, keytometa, main development

- email: elektra@berlakovich.net
- devel/test on: Debian


## Pino Toscano

Debian packaging, documentation

- email: pino@kde.org
- devel/test on: Debian


## Kai-Uwe Behrmann

test & packaging on CentOS, Fedora, OpenSUSE, RHEL and SLE

- email: kai-uwe@behrmann.name


## Christopher Meng

Fedora packaging

- email: cickumqt@gmail.com
- devel/test on: Fedora


## Ian S. Donnelly

Google Summer of Code 2014

- email: ian.s.donnelly@gmail.com
- devel/test on: Debian stable


## Charles Lindsay

ni library


## Gabriel Rauter

desktop environment integration & usability

- email: rauter.gabriel@gmail.com


## Avi Alkalay

initial concept & implementation, previous website

- email: avi@unix.sh


## Yannick Lecaillez

previous Mandriva packaging

- email: yl@itioweb.com


## Jens Andersen

bug fixing

- email: jens.andersen@gmail.com


## Patrick Sabin

trie development, previous python bindings

- email: patricksabin@gmx.at


## Studio-HB

design of Elektra logo & previous website

- email: contact@studio-hb.com


## Pier Luigi Fiorini

pkg-config file

- email: pierluigi.fiorini@mockup.org


## Rèmi

xml schema

- email: remipouak@yahoo.fr


## Andreas Rottmann

previous Debian packaging and 0.7 scheme bindings

- email: rotty@debian.org


## Simon Law

previous Debian packaging

- email: sfllaw@debian.org


## Daniel Bugl

documentation, web ui

- email: me@omnidan.net


## Kurt Micheli

optimizing ksLookup with order preserving minimal perfect hash map, markdown link converter for doxygen

- email: e1026558@student.tuwien.ac.at


## Alexander Rössler

improvements to the dbus plugin

- email: mail@roessler.systems


## Peter Nirschl

development of the crypto plugin, minor bug fixes, BSD/macOS support

- email: peter.nirschl@gmail.com
- github user: [petermax2](http://github.com/petermax2)
- devel on: Fedora
- test on: Fedora, Debian, macOS


## René Schwaiger

documentation, bug fixes

- email: sanssecours@me.com
- github user: [sanssecours](http://github.com/sanssecours)
- devel/test on: macOS


## Marvin Mall

development of the REST service & frontend for sharing of conf. snippets, cachefilter plugin, website

- email: marvin-mall@msn.com
- github user: [Namoshek](https://github.com/Namoshek)
- devel/test on: Debian Jessie


## Thomas Waser

main development, many plugins

- email: thomas.waser@libelektra.org
- github user: [tom-wa](https://github.com/tom-wa)
- devel/test on: Debian Testing/Sid


## Raffael Pancheri

design and implementation of the qt-gui

- email: raffael@libelektra.org
- github user: [0003088](https://github.com/0003088)


## Bernhard Denner

ruby bindings, ruby plugin, build server, Puppet module

- email: bernhard.denner@gmail.com
- github user: [BernhardDenner](https://github.com/BernhardDenner)
- devel/test on: Ubuntu and Debian

==> elektra-0.8.25.tar.gz: elektra-0.8.25/doc/AUTHORS.md <==
# Authors

This is a list of people that contributed to the Elektra project.


## Markus Raab

maintainer, main development, documentation, quality

- email: elektra@libelektra.org
- devel/test on: Debian


## Manuel Mausz

bindings, swig, gobject, main development

- email: manuel-elektra@mausz.at
- devel/test on: Fedora


## Felix Berlakovich

journald plugin, augeas plugin, keytometa, main development

- email: elektra@berlakovich.net
- devel/test on: Debian


## Pino Toscano

Debian packaging, documentation

- email: pino@kde.org
- devel/test on: Debian


## Kai-Uwe Behrmann

test & packaging on CentOS, Fedora, OpenSUSE, RHEL and SLE

- email: kai-uwe@behrmann.name


## Christopher Meng

Fedora packaging

- email: cickumqt@gmail.com
- devel/test on: Fedora


## Ian S. Donnelly

Google Summer of Code 2014

- email: ian.s.donnelly@gmail.com
- devel/test on: Debian stable


## Charles Lindsay

ni library


## Gabriel Rauter

desktop environment integration & usability

- email: rauter.gabriel@gmail.com


## Avi Alkalay

initial concept & implementation, previous website

- email: avi@unix.sh


## Yannick Lecaillez

previous Mandriva packaging

- email: yl@itioweb.com


## Jens Andersen

bug fixing

- email: jens.andersen@gmail.com


## Patrick Sabin

trie development, previous python bindings

- email: patricksabin@gmx.at


## Studio-HB

design of Elektra logo & previous website

- email: contact@studio-hb.com


## Pier Luigi Fiorini

pkg-config file

- email: pierluigi.fiorini@mockup.org


## Rèmi

xml schema

- email: remipouak@yahoo.fr


## Andreas Rottmann

previous Debian packaging and 0.7 scheme bindings

- email: rotty@debian.org


## Simon Law

previous Debian packaging

- email: sfllaw@debian.org


## Daniel Bugl

documentation, web ui

- email: me@omnidan.net


## Kurt Micheli

optimizing ksLookup with order preserving minimal perfect hash map, markdown link converter for doxygen

- email: e1026558@student.tuwien.ac.at


## Alexander Rössler

improvements to the dbus plugin

- email: mail@roessler.systems


## Peter Nirschl

development of the crypto plugin, minor bug fixes, BSD/macOS support

- email: peter.nirschl@gmail.com
- github user: [petermax2](http://github.com/petermax2)
- devel on: Fedora
- test on: Fedora, Debian, macOS


## René Schwaiger

documentation, bug fixes

- email: sanssecours@me.com
- github user: [sanssecours](http://github.com/sanssecours)
- devel/test on: macOS


## Marvin Mall

development of the REST service & frontend for sharing of conf. snippets, cachefilter plugin, website

- email: marvin-mall@msn.com
- github user: [Namoshek](https://github.com/Namoshek)
- devel/test on: Debian Jessie


## Thomas Waser

main development, many plugins

- email: thomas.waser@libelektra.org
- github user: [tom-wa](https://github.com/tom-wa)
- devel/test on: Debian Testing/Sid


## Raffael Pancheri

design and implementation of the qt-gui

- email: raffael@libelektra.org
- github user: [0003088](https://github.com/0003088)


## Bernhard Denner

ruby bindings, ruby plugin, build server, Puppet module

- email: bernhard.denner@gmail.com
- github user: [BernhardDenner](https://github.com/BernhardDenner)
- devel/test on: Ubuntu and Debian

## Thomas Wahringer

notification system, I/O bindings

- email: waht@libelektra.org
- github user: [waht](https://github.com/waht)
- devel/test on: Debian

## Mihael Pranjić

development of the mmapstorage plugin

- email: mpranj@limun.org
- github user: [mpranj](https://github.com/mpranj)
- devel/test on: Fedora, Debian, macOS
